local AddonName, TA = ...

-- Config Panel Text Strings
TA.Text={
Title = "Taunt Aware",
TitleSub = "Change how Taunt Aware behaves by setting the options below",
Enable = "Enable the Add On to function",
Full = "Enable full warnings (if you are not a tank)",
AlertSound = "Play a sound when you get a taunt alert",
MF = "Use the Message Frame instead of chat for alerts",
FontSize = "Font Size in message frame",
FadeDelay  = "                            How long the messages display in the frame [1-60 secs]",
TauntsOnly = "Select how to react to high threat actions ( on = ignore, off = tattle, monitor = just alert yourself )",
Links = "Show skill links instead of just skill names",
Scan = "Scan the group for threat increasing abilities when members change",
ScanDelay = "                                    Wait how long after members change for the scan [1-60 secs]",
Tattle = "Alert other people when fight is over to taunts used by non tanks",
TatMode = "How to send the alert [GROUP/WHISPER/SUMMARY](Summary just outputs to you)",
}

-- Bill's Utils
local ChkBox = BillsUtils.ChkBox
local ChkBoxSave = BillsUtils.ChkBoxSave
local CheckClick = BillsUtils.CheckClick
local SliderSave = BillsUtils.SliderSave
local SliderMW = BillsUtils.SliderMW
local Slider = BillsUtils.Slider
local SliderEditBox = BillsUtils.SliderEditBox
local SJprint = BillsUtils.SJprint


local X = 16 -- standard Horizontal Spacing
local Y = 35 -- standard Vertical spacing 26
local TxtY = 13



-- General Settings / functions
local TAS = TauntAware_Settings
local TAD

TA.ConfigFrame = CreateFrame("Frame")
TA.ConfigFrame:RegisterEvent("ADDON_LOADED")

TA.ConfigFrame:SetScript("OnEvent",function(self, event, ...)
	local arg = ...
	if event ~= "ADDON_LOADED" and arg ~= AddonName then return end
	TAS = TA.TAS
	TAD = TA.TAD
end)

TA.Checkclick = function()
	PlaySound( "GAMEGENERICBUTTONPRESS" )
end

local PlayTestSound = function( sound )
	local file
	if sound == 2 then
		file = "Interface\\AddOns\\TauntAware\\Alert1.mp3"
	elseif sound == 3 then
	file = "Interface\\AddOns\\TauntAware\\Alert2.mp3"
	elseif sound == 4 then
	file = "Interface\\AddOns\\TauntAware\\Alert3.mp3"
	elseif sound == 5 then
	file = "Interface\\AddOns\\TauntAware\\Alert4.mp3"
	elseif sound == 6 then
	file = "Interface\\AddOns\\TauntAware\\Alert5.mp3"
	elseif sound == 7 then
	file = "Interface\\AddOns\\TauntAware\\Alert6.mp3"
	elseif sound == 8 then
	file = "Interface\\AddOns\\TauntAware\\Alert7.mp3"
	elseif sound == 9 then
	file = "Interface\\AddOns\\TauntAware\\Alert8.mp3"
	elseif sound == 10 then
	file = "Interface\\AddOns\\TauntAware_CustomSounds\\custom.mp3"
	elseif sound == 11 then
	file = "Interface\\AddOns\\TauntAware_CustomSounds\\custom.ogg"
	else
		return
	end
	PlaySoundFile( file )
end
--Panel
TA.panel = CreateFrame( "Frame", "TauntAwareConfig", UIParent )
local me = TA.panel
me:SetScript("OnLoad", function()
	me.init()
end)


me.name = "Taunt Aware"

-- Panel title
local Title = me:CreateFontString( nil, "ARTWORK", "GameFontNormalLarge" )
Title:SetPoint( "TOPLEFT", 16, -16 )
Title:SetText( TA.Text.Title )
local SubText = me:CreateFontString( nil, "ARTWORK", "GameFontHighlightSmall" )
SubText:SetPoint( "TOPLEFT", Title, "BOTTOMLEFT", 0, -8 )
SubText:SetPoint( "RIGHT", -32, 0 )
SubText:SetHeight( 32 )
SubText:SetJustifyH( "LEFT" )
SubText:SetJustifyV( "TOP" )
SubText:SetText( TA.Text.TitleSub )

-- Check Boxes & Text
local last = SubText
local Command = {"Enable", "Full",}
for x = 1, #Command do
	me[ Command[x] ] = ChkBox( last , "TauntAwareCfg", Command[x] , me, CheckClick, TA.Text )
	last = me[ Command[x] ]
end


-- AlertSound
local AlertSoundModes = {"off", "alert1.mp3", "alert2.mp3", "alert3.mp3", "alert4.mp3", "alert5.mp3", "alert6.mp3", "alert7.mp3", "alert8.mp3", "custom.mp3", "custom.ogg" }
local checked
local function OnClick(self)
	UIDropDownMenu_SetSelectedID( UIDROPDOWNMENU_OPEN_MENU, self:GetID())
	PlayTestSound( self:GetID() )
	checked = self:GetID()
end

local function initialize(self, level)
	local info, selected
		
	for count = 1, #AlertSoundModes  do
		if TAS.AlertSound == AlertSoundModes[count] then
			selected = count
		end
		info = UIDropDownMenu_CreateInfo()
		info.text = AlertSoundModes[count]
		info.value = AlertSoundModes[count]
		info.checked = function(self)
			if UIDropDownMenu_GetSelectedID(me.AlertSound) == self:GetID() then
				return true
			else 
				return false
			end
		end
		info.func = OnClick
		UIDropDownMenu_AddButton(info, level)
	end
	
	UIDropDownMenu_SetSelectedID( UIDROPDOWNMENU_INIT_MENU , selected ) 
end

local AlertSoundText = me:CreateFontString( nil, "ARTWORK", "GameFontHighlightSmall" )
AlertSoundText:SetPoint( "TOPLEFT", last, "BOTTOMLEFT", 0, -0 )
AlertSoundText:SetPoint( "RIGHT", -32, 0 )
AlertSoundText:SetHeight( 32 )
AlertSoundText:SetJustifyH( "LEFT" )
AlertSoundText:SetJustifyV( "CENTER" )
AlertSoundText:SetText( TA.Text.AlertSound )

last = AlertSoundText

me.AlertSound = CreateFrame("Button", "TauntAwareCfgAlertSound", me, "UIDropDownMenuTemplate")
me.AlertSound.displayMode = "MENU"
me.AlertSound:ClearAllPoints()
me.AlertSound:SetPoint("TOPLEFT", last, "BOTTOMLEFT", 0, 0)
UIDropDownMenu_Initialize( me.AlertSound, initialize)
UIDropDownMenu_SetWidth( me.AlertSound, 100);
UIDropDownMenu_SetButtonWidth( me.AlertSound, 124)
UIDropDownMenu_JustifyText( me.AlertSound, "LEFT")
		
last = me.AlertSound


-- Message Frame Check Box
me.MF = ChkBox( last , "TauntAwareCfg", "MF" , me, CheckClick, TA.Text )
last = me.MF

local FontSizeDemo
local SliderFontSize = function(self, delta)
	local min,max = self:GetMinMaxValues()
	local step = self:GetValueStep()
	local value = self:GetValue()

	if delta < 0 then 
		value = value - step
	elseif delta > 0 then
		value = (value + step)
	end
	if value < min then
		value = min
	elseif value > max then
		value = max
	end
	self:SetValue( value )
	FontSizeDemo:SetFont( STANDARD_TEXT_FONT, value )
	FontSizeDemo:SetText( "Font Size Demo "..tostring(value) )
end
	
me.FontSize = Slider( last , "TauntAwareCfg", "FontSize", me , SliderFontSize , TA.Text, 7, 24, 1 )
me.FontSize:SetScript( "OnValueChanged", function( self )
	local val = self:GetValue()
	self.Val:SetNumber( val )
	FontSizeDemo:SetFont( STANDARD_TEXT_FONT, val )
	FontSizeDemo:SetText( "Font Size Demo "..tostring( val ) )
	PlaySound( "GAMEGENERICBUTTONPRESS" )
end)
	
last = me.FontSize
me.FontSize.Val = SliderEditBox( last , "TauntAwareCfg", "FontSizeDemo", me )
	
FontSizeDemo = me:CreateFontString( "TauntAwareFontSizeDemo", "ARTWORK") --, "GameFontHighlightSmall" )
FontSizeDemo:SetFont( STANDARD_TEXT_FONT, 10 )
FontSizeDemo:SetPoint( "TOPLEFT", last, "BOTTOMLEFT", 0, -0 )
FontSizeDemo:SetPoint( "RIGHT", -32, 0 )
FontSizeDemo:SetHeight( 32 )
FontSizeDemo:SetJustifyH( "LEFT" )
FontSizeDemo:SetJustifyV( "CENTER" )
FontSizeDemo:SetText( "Font Size Demo" )

last = FontSizeDemo

me.FadeDelay = Slider( last , "TauntAwareCfg", "FadeDelay", me , SliderMW , TA.Text, 1, 60, 1 )
last = me.FadeDelay
me.FadeDelay.Val = SliderEditBox( last , "TauntAwareCfg", "FadeDelay", me )

--"TauntsOnly" goes here
local TauntsOnlyModes = {"on", "off", "monitor" }

local function OnClick(self)
	local index = self:GetID()
	UIDropDownMenu_SetSelectedID( UIDROPDOWNMENU_OPEN_MENU, self:GetID())
end

local function initialize(self, level)
	local info, selected
		
	for count = 1, #TauntsOnlyModes  do
		if TAS.TauntsOnly == TauntsOnlyModes[count] then
			selected = count
		end
		info = UIDropDownMenu_CreateInfo()
		info.text = TauntsOnlyModes[count]
		info.checked = function(self)
			if UIDropDownMenu_GetSelectedID(me.TauntsOnly) == self:GetID() then
				return true
			else 
				return false
			end
		end
		info.func = OnClick
		UIDropDownMenu_AddButton(info, level)
	end
	UIDropDownMenu_SetSelectedID( UIDROPDOWNMENU_INIT_MENU , selected ) 
end

local TauntsOnlyText = me:CreateFontString( nil, "ARTWORK", "GameFontHighlightSmall" )
TauntsOnlyText:SetPoint( "TOPLEFT", last, "BOTTOMLEFT", 0, -0 )
TauntsOnlyText:SetPoint( "RIGHT", -32, 0 )
TauntsOnlyText:SetHeight( 32 )
TauntsOnlyText:SetJustifyH( "LEFT" )
TauntsOnlyText:SetJustifyV( "CENTER" )
TauntsOnlyText:SetText( TA.Text.TauntsOnly )

last = TauntsOnlyText

me.TauntsOnly = CreateFrame("Button", "TauntAwareCfgTauntsOnly", me, "UIDropDownMenuTemplate")
me.TauntsOnly.displayMode = "MENU"
me.TauntsOnly:ClearAllPoints()
me.TauntsOnly:SetPoint("TOPLEFT", last, "BOTTOMLEFT", 0, 0)
UIDropDownMenu_Initialize( me.TauntsOnly, initialize)
UIDropDownMenu_SetWidth( me.TauntsOnly, 100);
UIDropDownMenu_SetButtonWidth( me.TauntsOnly, 124)
UIDropDownMenu_JustifyText( me.TauntsOnly, "LEFT")
		
last = me.TauntsOnly

Command = { "Links", "Scan"}
for x = 1, #Command do
	me[ Command[x] ] = ChkBox( last , "TauntAwareCfg", Command[x] , me, CheckClick, TA.Text )
	last = me[ Command[x] ]
end
	
me.ScanDelay = Slider( last , "TauntAwareCfg", "ScanDelay", me , SliderMW , TA.Text, 1, 60, 1 )
last = me.ScanDelay
me.ScanDelay.Val = SliderEditBox( last , "TauntAwareCfg", "ScanDelay", me )
	
me.Tattle = ChkBox( last , "TauntAwareCfg", "Tattle" , me, CheckClick, TA.Text )
last = me.Tattle

--Tat Mode
local TatModes = {"GROUP", "WHISPER", "SUMMARY" }

local function OnClick(self)
	local index = self:GetID()
	UIDropDownMenu_SetSelectedID( UIDROPDOWNMENU_OPEN_MENU, self:GetID())
end

local function initialize(self, level)
	local info, selected
	
	for count = 1, #TatModes  do
		if TAS.TatMode == TatModes[count] then
			selected = count
		end
		info = UIDropDownMenu_CreateInfo()
		info.text = TatModes[count]
		info.checked = function(self)
			if UIDropDownMenu_GetSelectedID(me.TatMode) == self:GetID() then
				return true
			else 
				return false
			end
		end
		info.func = OnClick
		UIDropDownMenu_AddButton(info, level)
	end
	UIDropDownMenu_SetSelectedID( UIDROPDOWNMENU_INIT_MENU , selected ) 
end

local TatModeText = me:CreateFontString( nil, "ARTWORK", "GameFontHighlightSmall" )
TatModeText:SetPoint( "TOPLEFT", last, "BOTTOMLEFT", 0, -0 )
TatModeText:SetPoint( "RIGHT", -32, 0 )
TatModeText:SetHeight( 32 )
TatModeText:SetJustifyH( "LEFT" )
TatModeText:SetJustifyV( "CENTER" )
TatModeText:SetText( TA.Text.TatMode )

last = TatModeText

me.TatMode = CreateFrame("Button", "TauntAwareCfgTatMode", me, "UIDropDownMenuTemplate")
me.TatMode.displayMode = "MENU"
me.TatMode:ClearAllPoints()
me.TatMode:SetPoint("TOPLEFT", last, "BOTTOMLEFT", 0, 0)
UIDropDownMenu_Initialize( me.TatMode, initialize)
UIDropDownMenu_SetWidth( me.TatMode, 100);
UIDropDownMenu_SetButtonWidth( me.TatMode, 124)
UIDropDownMenu_JustifyText( me.TatMode, "LEFT")
		
last = me.TatMode




--	End of frame



-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- X  Init / Reset the config panel to match current settings                                                     X
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
--

me.Init = function(...)
	me.Enable:SetChecked( TAS.Enable )
	me.Full:SetChecked( TAS.Full )
	ToggleDropDownMenu( nil, nil, me.AlertSound ) 
	ToggleDropDownMenu( nil, nil, me.AlertSound )
	me.MF:SetChecked( TAS.MF )
	me.FadeDelay:SetValue( TAS.FadeDelay)
	me.FadeDelay.Val:SetCursorPosition( 0 )
	me.FadeDelay.Val:SetNumber( TAS.FadeDelay )
	me.FontSize:SetValue( TAS.FontSize)
	me.FontSize.Val:SetCursorPosition( 0 )
	me.FontSize.Val:SetNumber( TAS.FontSize )
	ToggleDropDownMenu( nil, nil, me.TauntsOnly ) 
	ToggleDropDownMenu( nil, nil, me.TauntsOnly )
	if UIDROPDOWNMENU_OPEN_MENU == me.TauntsOnly then
		ToggleDropDownMenu( nil, nil, me.TauntsOnly )
	end
	me.Links:SetChecked( TAS.Links )
	me.Scan:SetChecked( TAS.Scan )
	me.ScanDelay:SetValue( TAS.ScanDelay)
	me.ScanDelay.Val:SetCursorPosition( 0 )
	me.ScanDelay.Val:SetNumber( TAS.ScanDelay )
	me.Tattle:SetChecked( TAS.Tattle )
	ToggleDropDownMenu( nil, nil, me.TatMode ) 
	ToggleDropDownMenu( nil, nil, me.TatMode )
	if UIDROPDOWNMENU_OPEN_MENU == me.TatMode then
		ToggleDropDownMenu( nil, nil, me.TatMode )
	end
	
end

-- Reset config panel and settings to DEFAULT
me.Reset = function(...)
	local Command = {"Enable", "Full","AlertSound", "MF", "FontSize", "FadeDelay", "TauntsOnly", "AlertTauntsOnly", "TattleTauntsOnly", "Links", "Scan", "ScanDelay", "Tattle", "TatMode"}
	for x = 1, #Command do
		TAS.Command[x] = TAD.Command[x]
	end
	me.Init()
end



me.refresh = function(self)
	me.Init()
end

me.default = function (self)
	me.Reset()
end

me.cancel = function (self)
	me.Init()
end


-- Save settings from config panel
me.okay = function(self)
	local Command = {"Enable", "Full", "MF", "Links", "Scan", "Tattle"}
	for x = 1, #Command do
		ChkBoxSave( me, Command[x], TAS)
	end
	SliderSave( me, "FontSize", TAS) 
	SliderSave( me, "FadeDelay", TAS)
	SliderSave( me, "ScanDelay", TAS)
	
	if TAS.AlertSound ~= AlertSoundModes[UIDropDownMenu_GetSelectedID(me.AlertSound)] then
		TAS.AlertSound = AlertSoundModes[UIDropDownMenu_GetSelectedID(me.AlertSound)]
	end
	
	if TAS.TauntsOnly ~= TauntsOnlyModes[UIDropDownMenu_GetSelectedID(me.TauntsOnly)] then
		TAS.TauntsOnly = TauntsOnlyModes[UIDropDownMenu_GetSelectedID(me.TauntsOnly)]
	end
	
	if TAS.TatMode ~= TatModes[UIDropDownMenu_GetSelectedID(me.TatMode)] then
		TAS.TatMode = TatModes[UIDropDownMenu_GetSelectedID(me.TatMode)]
	end
	
	
	NickAlert.EventManager()
end

-- Register the config panel
InterfaceOptions_AddCategory( me )
